==> moodle_1.3.1.orig.tar.gz: moodle/lang/pl/forum.php <==
<?PHP // $Id: forum.php,v 1.13 2004/03/05 13:40:53 adamtpaw Exp $ 
      // forum.php - created with Moodle 1.2 Beta (2004022400)


$string['addanewdiscussion'] = 'Dodaj nowy temat dyskusji';
$string['addanewtopic'] = ' Dodaj nowy temat';
$string['allowchoice'] = 'Zezwl kademu uytkownikowi na wybr';
$string['allowdiscussions'] = 'Czy $a moe wysya wiadomoci na to forum?';
$string['allowratings'] = 'Czy posty mog by oceniane?';
$string['allowsdiscussions'] = 'W tym forum kady moe utworzy tylko jeden temat dyskusji.';
$string['anyfile'] = 'Jakikolwiek plik';
$string['attachment'] = 'Zacznik';
$string['bynameondate'] = ' $a->name  w dniu $a->date napisa(a)';
$string['configdisplaymode'] = ' Domylny tryb wywietlania dyskusji, jeli nie wybrano innego.';
$string['configlongpost'] = ' Kady post o dugoci przekraczajcej t liczb (nie uwzgldniajc kodu HTML) jest uwaany za dugi.';
$string['configmanydiscussions'] = ' Maksymalna ilo dyskusji pokazywanych na jednej stronie forum.';
$string['configmaxbytes'] = 'Domylna wielko plikw dla wszystkich zacznikw na tej stronie (chyba, e przedmiot bd ustawienia strony nakadaj jeszcze inne ograniczenia)';
$string['configshortpost'] = ' Kady post o dugoci mniejszej od tej liczby (nie uwzgldniajc kodu HTML) jest uwaany za krtki';
$string['couldnotadd'] = 'Nie mona doda twojego postu z powodu nieznanego bdu';
$string['couldnotdeleteratings'] = 'Niestety, nie mona byo  usun tego postu, gdy zosta on ju oceniony przez innych';
$string['couldnotdeletereplies'] = 'Niestety, nie mona byo  usun tego postu, gdy inni uytkownicy ju na niego odpowiedzieli.';
$string['couldnotupdate'] = 'Nie mona zaktualizowa twojego postu z powodu nieznanego bdu';
$string['delete'] = 'Usu';
$string['deleteddiscussion'] = 'Usunito temat dyskusji';
$string['deletedpost'] = 'Post zosta usunity';
$string['deletesure'] = 'Czy masz pewno, e chcesz usun te post?';
$string['discussion'] = 'Dyskusja';
$string['discussionmoved'] = 'Dyskusja ta zostaa przeniesiona do \'$a \'.';
$string['discussions'] = 'Dyskusje';
$string['discussionsstartedby'] = 'Dyskusje rozpoczte przez $a';
$string['discussionsstartedbyrecent'] = ' Dyskusje rozpoczte ostatnio przez $a';
$string['discussthistopic'] = 'Podyskutuj na ten temat';
$string['eachuserforum'] = 'Kady wysya jeden temat dyskusji';
$string['edit'] = 'Edycja';
$string['editing'] = 'Edycja';
$string['emptymessage'] = 'Co nie tak z twoim postem. By moe by  pusty lub zacznik by zbyt duy. Twoje zmiany nie zostay zapisane';
$string['everyonecanchoose'] = 'Kady moe si zapisa na forum';
$string['everyoneissubscribed'] = 'Kady jest zapisany na to forum';
$string['forcesubscribe'] = 'Kady jest automatycznie zapisywany na to forum';
$string['forcesubscribeq'] = 'Wymusi u kadego zapis na to forum?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Wstp';
$string['forumname'] = 'Nazwa Forum';
$string['forums'] = 'Fora dyskusyjne';
$string['forumtype'] = 'Rodzaj forum';
$string['generalforum'] = 'Forum standardowe do uytku oglnego';
$string['generalforums'] = 'Fora oglne';
$string['inforum'] = 'w $a';
$string['intronews'] = 'Wiadomoci i ogoszenia';
$string['introsocial'] = 'Forum otwarte do dyskusji na dowolny temat';
$string['introteacher'] = 'Forum wycznie dla prowadzcych';
$string['lastpost'] = 'Ostatni post';
$string['learningforums'] = 'Forum dydaktyczne';
$string['maxattachmentsize'] = 'Maksymalna wielko zacznika';
$string['maxtimehaspassed'] = 'Niestety, maksymalny czas dozwolony na edycj tego postu ($a) min!';
$string['message'] = 'Wiadomo';
$string['modeflatnewestfirst'] = 'Wywietl odpowiedzi pasko, z najnowszymi na pocztku';
$string['modeflatoldestfirst'] = 'Wywietl odpowiedzi pasko, z najdawniejszymi na pocztku';
$string['modenested'] = 'Wywietl odpowiedzi tematycznie';
$string['modethreaded'] = 'Wywietl odpowiedzi wtkami';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Fora dyskusyjne';
$string['more'] = 'Wicej';
$string['movethisdiscussionto'] = 'Przenie t dyskusj do ...';
$string['namenews'] = 'Forum aktualnoci';
$string['namesocial'] = 'Forum towarzyskie';
$string['nameteacher'] = 'Forum nauczycielskie';
$string['newforumposts'] = 'Nowe wiadomoci na forum';
$string['nodiscussions'] = 'Nie ma adnych tematw na tym forum';
$string['noguestpost'] = 'Niestety gocie nie mog zabiera gosu na tym forum';
$string['nomorepostscontaining'] = ' Nie znaleziono wicej postw zawierajcych \'$a\'';
$string['nonews'] = ' Nie umieszczono jeszcze adnych nowoci';
$string['noposts'] = 'Brak wiadomoci';
$string['nopostscontaining'] = 'Nie znaleziono wiadomoci zawierajcych \'$a \'';
$string['nosubscribers'] = 'Nikt jeszcze nie zapisa si na to forum';
$string['notingroup'] = 'Musisz by zapisany do grupy aby mc przeglda to forum.';
$string['nownotsubscribed'] = '$a ->name NIE bdzie otrzymywa kopii \'$a->forum\' poczt elektroniczn.';
$string['nowsubscribed'] = '$a->name bdzie otrzymywa kopie \'$a->forum\' poczt elektroniczn.';
$string['numposts'] = '$a wiadomoci';
$string['olderdiscussions'] = 'Starsze dyskusje';
$string['openmode0'] = 'adnych dyskusji, adnych odpowiedzi';
$string['openmode1'] = 'adnych dyskusji, ale odpowiedzi s dozwolone';
$string['openmode2'] = 'Dyskusje i odpowiedzi s dozwolone';
$string['parent'] = 'Przejd do wiadomoci wyej (&#8222;parent&#8221;)';
$string['parentofthispost'] = 'Wiadomo nadrzdna';
$string['postadded'] = 'Twj post zosta dodany. <P>Jeeli chcesz co jeszcze zmieni masz $a na edycj.';
$string['postincontext'] = 'Zobacz ten post w kontekcie';
$string['postmailinfo'] = 'To jest kopia wiadomoci wysanej przez serwis  $a. Aby doda odpowied poprzez stron WWW kliknij poniszy link:';
$string['postrating1'] = 'Demonstruje gwnie poznawanie odrbne';
$string['postrating2'] = 'Demonstruje w rwnym stopniu poznawanie odrbne i powizane';
$string['postrating3'] = 'Demonstruje gwnie poznawanie powizane';
$string['posts'] = 'Posty';
$string['postupdated'] = 'Twj post zosta zaktualizowany';
$string['processingpost'] = 'Post $a jest w trakcie przetwarzania';
$string['rate'] = 'Oce';
$string['rating'] = ' Oceny';
$string['ratingeveryone'] = ' Kady moe oceni posty';
$string['ratingno'] = ' Brak ocen';
$string['ratingonlyteachers'] = ' Tylko $a moe ocenia posty';
$string['ratingpublic'] = '$a moe zobaczy oceny wszystkich';
$string['ratingpublicnot'] = '$a moe zobaczy tylko swoje oceny';
$string['ratings'] = 'Oceny';
$string['ratingssaved'] = 'Oceny zostay zapisane';
$string['ratingsuse'] = ' Wykorzystanie ocen';
$string['ratingtime'] = ' Ogranicz wystawianie ocen do postw w nastpujcym przedziale czasowym :';
$string['re'] = 'Odp:';
$string['readtherest'] = 'Przeczytaj reszt tematu';
$string['replies'] = 'Odpowiedzi';
$string['repliesmany'] = '$a odpowiedzi  (jak dotd)';
$string['repliesone'] = '$a odpowied (jak dotd)';
$string['reply'] = 'Odpowiedz';
$string['replyforum'] = 'Odpwiedz forum';
$string['search'] = 'Szukaj';
$string['searchforums'] = 'Szukaj w forach';
$string['searcholderposts'] = 'Przeszukaj dawniejsze posty...';
$string['searchresults'] = 'Szukaj w rezultatach';
$string['sendinratings'] = 'Wylij moje ostatnie oceny';
$string['showsubscribers'] = 'Wywietl uytkownikw zapisanych na forum';
$string['singleforum'] = 'Pojedyncza prosta dyskusja';
$string['startedby'] = 'Rozpoczta przez';
$string['subject'] = 'Temat';
$string['subscribe'] = 'Zapisz si na to forum';
$string['subscribed'] = 'Zapisany na forum';
$string['subscribers'] = 'Zapisani na forum';
$string['subscribersto'] = 'Zapisani na \'$a \'';
$string['subscribestart'] = 'Przesyaj mi kopie postw z tego forum poczt elektroniczn';
$string['subscribestop'] = 'Nie chc otrzymywa kopii postw z tego forum';
$string['subscription'] = 'Zapisanie si na forum';
$string['subscriptions'] = 'Zapisy na fora';
$string['unsubscribe'] = 'Wypisz si z tego forum';
$string['unsubscribed'] = 'Wypisany z forum';
$string['youratedthis'] = 'Ocenie(a) to';
$string['yournewtopic'] = 'Twoja nowa dyskusja';
$string['yourreply'] = 'Twoja odpowied';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.4 (2004083100)


$string['addanewdiscussion'] = 'Dodaj nowy temat dyskusji';
$string['addanewtopic'] = ' Dodaj nowy temat';
$string['allowchoice'] = 'Zezwl kademu uytkownikowi na wybr';
$string['allowdiscussions'] = 'Czy $a moe wysya wiadomoci na to forum?';
$string['allowratings'] = 'Czy posty mog by oceniane?';
$string['allowsdiscussions'] = 'W tym forum kady moe utworzy tylko jeden temat dyskusji.';
$string['anyfile'] = 'Jakikolwiek plik';
$string['attachment'] = 'Zacznik';
$string['bynameondate'] = ' $a->name  w dniu $a->date napisa(a)';
$string['configdisplaymode'] = ' Domylny tryb wywietlania dyskusji, jeli nie wybrano innego.';
$string['configenablerssfeeds'] = 'Umoliwia RSS feeds dla wszystkich forw dyskusyjnych. Musisz jednak i tak wczy obsug feeds manualnie dla kadego forum.';
$string['configlongpost'] = ' Kady post o dugoci przekraczajcej t liczb (nie uwzgldniajc kodu HTML) jest uwaany za dugi.';
$string['configmanydiscussions'] = ' Maksymalna ilo dyskusji pokazywanych na jednej stronie forum.';
$string['configmaxbytes'] = 'Domylna wielko plikw dla wszystkich zacznikw na tej stronie (chyba, e przedmiot bd ustawienia strony nakadaj jeszcze inne ograniczenia)';
$string['configreplytouser'] = 'Czy wysany post powinien zawiera email wysyajcego, tak aby mogli do niego osobicie odpowiedzie (zamiast poprzez forum)? Nawet przy wyborze \"Tak\" uytkownicy mog wybra w swoich profilach, e chc ukry swj adres email. ';
$string['configshortpost'] = ' Kady post o dugoci mniejszej od tej liczby (nie uwzgldniajc kodu HTML) jest uwaany za krtki';
$string['couldnotadd'] = 'Nie mona doda twojego postu z powodu nieznanego bdu';
$string['couldnotdeleteratings'] = 'Niestety, nie mona byo  usun tego postu, gdy zosta on ju oceniony przez innych';
$string['couldnotdeletereplies'] = 'Niestety, nie mona byo  usun tego postu, gdy inni uytkownicy ju na niego odpowiedzieli.';
$string['couldnotupdate'] = 'Nie mona zaktualizowa twojego postu z powodu nieznanego bdu';
$string['delete'] = 'Usu';
$string['deleteddiscussion'] = 'Usunito temat dyskusji';
$string['deletedpost'] = 'Post zosta usunity';
$string['deletesure'] = 'Czy masz pewno, e chcesz usun te post?';
$string['digestmailheader'] = 'To jest twje dzienne streszczenie postw z forum $a-sitename. Aby zmieni emailowe preferencje forum, id do $a->userprefs.';
$string['digestmailprefs'] = 'profil uytkownika';
$string['digestmailsubject'] = '$a: streszczenie postw';
$string['digestsentusers'] = 'Wysano do uytkownika $a';
$string['discussion'] = 'Dyskusja';
$string['discussionmoved'] = 'Dyskusja ta zostaa przeniesiona do \'$a \'.';
$string['discussionname'] = 'Nazwa dyskusji';
$string['discussions'] = 'Dyskusje';
$string['discussionsstartedby'] = 'Dyskusje rozpoczte przez $a';
$string['discussionsstartedbyrecent'] = ' Dyskusje rozpoczte ostatnio przez $a';
$string['discussthistopic'] = 'Podyskutuj na ten temat';
$string['eachuserforum'] = 'Kady wysya jeden temat dyskusji';
$string['edit'] = 'Edycja';
$string['editing'] = 'Edycja';
$string['emptymessage'] = 'Co nie tak z twoim postem. By moe by  pusty lub zacznik by zbyt duy. Twoje zmiany nie zostay zapisane';
$string['everyonecanchoose'] = 'Kady moe si zapisa na forum';
$string['everyoneissubscribed'] = 'Kady jest zapisany na to forum';
$string['existingsubscribers'] = 'Istniejcy subskrybenci';
$string['forcesubscribe'] = 'Kady jest automatycznie zapisywany na to forum';
$string['forcesubscribeq'] = 'Wymusi u kadego zapis na to forum?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Wstp';
$string['forumname'] = 'Nazwa Forum';
$string['forums'] = 'Fora dyskusyjne';
$string['forumtype'] = 'Rodzaj forum';
$string['generalforum'] = 'Forum standardowe do uytku oglnego';
$string['generalforums'] = 'Fora oglne';
$string['inforum'] = 'w $a';
$string['intronews'] = 'Wiadomoci i ogoszenia';
$string['introsocial'] = 'Forum otwarte do dyskusji na dowolny temat';
$string['introteacher'] = 'Forum wycznie dla prowadzcych';
$string['lastpost'] = 'Ostatni post';
$string['learningforums'] = 'Forum dydaktyczne';
$string['maxattachmentsize'] = 'Maksymalna wielko zacznika';
$string['maxtimehaspassed'] = 'Niestety, maksymalny czas dozwolony na edycj tego postu ($a) min!';
$string['message'] = 'Wiadomo';
$string['modeflatnewestfirst'] = 'Wywietl odpowiedzi pasko, z najnowszymi na pocztku';
$string['modeflatoldestfirst'] = 'Wywietl odpowiedzi pasko, z najdawniejszymi na pocztku';
$string['modenested'] = 'Wywietl odpowiedzi tematycznie';
$string['modethreaded'] = 'Wywietl odpowiedzi wtkami';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Fora dyskusyjne';
$string['more'] = 'Wicej';
$string['movethisdiscussionto'] = 'Przenie t dyskusj do ...';
$string['namenews'] = 'Forum aktualnoci';
$string['namesocial'] = 'Forum towarzyskie';
$string['nameteacher'] = 'Forum nauczycielskie';
$string['newforumposts'] = 'Nowe wiadomoci na forum';
$string['nodiscussions'] = 'Nie ma adnych tematw na tym forum';
$string['noguestpost'] = 'Niestety gocie nie mog zabiera gosu na tym forum';
$string['nomorepostscontaining'] = ' Nie znaleziono wicej postw zawierajcych \'$a\'';
$string['nonews'] = ' Nie umieszczono jeszcze adnych nowoci';
$string['noposts'] = 'Brak wiadomoci';
$string['nopostscontaining'] = 'Nie znaleziono wiadomoci zawierajcych \'$a \'';
$string['nosubscribers'] = 'Nikt jeszcze nie zapisa si na to forum';
$string['notingroup'] = 'Musisz by zapisany do grupy aby mc przeglda to forum.';
$string['nownotsubscribed'] = '$a ->name NIE bdzie otrzymywa kopii \'$a->forum\' poczt elektroniczn.';
$string['nowsubscribed'] = '$a->name bdzie otrzymywa kopie \'$a->forum\' poczt elektroniczn.';
$string['numposts'] = '$a wiadomoci';
$string['olderdiscussions'] = 'Starsze dyskusje';
$string['openmode0'] = 'adnych dyskusji, adnych odpowiedzi';
$string['openmode1'] = 'adnych dyskusji, ale odpowiedzi s dozwolone';
$string['openmode2'] = 'Dyskusje i odpowiedzi s dozwolone';
$string['parent'] = 'Przejd do wiadomoci wyej (&#8222;parent&#8221;)';
$string['parentofthispost'] = 'Wiadomo nadrzdna';
$string['postadded'] = 'Twj post zosta dodany. <P>Jeeli chcesz co jeszcze zmieni masz $a na edycj.';
$string['postincontext'] = 'Zobacz ten post w kontekcie';
$string['postmailinfo'] = 'To jest kopia wiadomoci wysanej przez serwis  $a. Aby doda odpowied poprzez stron WWW kliknij poniszy link:';
$string['postrating1'] = 'Demonstruje gwnie poznawanie odrbne';
$string['postrating2'] = 'Demonstruje w rwnym stopniu poznawanie odrbne i powizane';
$string['postrating3'] = 'Demonstruje gwnie poznawanie powizane';
$string['posts'] = 'Posty';
$string['posttoforum'] = 'Post do forum';
$string['postupdated'] = 'Twj post zosta zaktualizowany';
$string['potentialsubscribers'] = 'Potencjalni subskrybenci';
$string['processingdigest'] = 'Przetwaanie streszczenia maili uytkownika $a';
$string['processingpost'] = 'Post $a jest w trakcie przetwarzania';
$string['prune'] = 'Zerwij';
$string['prunedpost'] = 'Z tego postu zostaa utworzona nowa dyskusja';
$string['pruneheading'] = 'Zerwij post i przejd do nowej dyskusji';
$string['rate'] = 'Oce';
$string['rating'] = ' Oceny';
$string['ratingeveryone'] = ' Kady moe oceni posty';
$string['ratingno'] = ' Brak ocen';
$string['ratingonlyteachers'] = ' Tylko $a moe ocenia posty';
$string['ratingpublic'] = '$a moe zobaczy oceny wszystkich';
$string['ratingpublicnot'] = '$a moe zobaczy tylko swoje oceny';
$string['ratings'] = 'Oceny';
$string['ratingssaved'] = 'Oceny zostay zapisane';
$string['ratingsuse'] = ' Wykorzystanie ocen';
$string['ratingtime'] = ' Ogranicz wystawianie ocen do postw w nastpujcym przedziale czasowym :';
$string['re'] = 'Odp:';
$string['readtherest'] = 'Przeczytaj reszt tematu';
$string['replies'] = 'Odpowiedzi';
$string['repliesmany'] = '$a odpowiedzi  (jak dotd)';
$string['repliesone'] = '$a odpowied (jak dotd)';
$string['reply'] = 'Odpowiedz';
$string['replyforum'] = 'Odpwiedz forum';
$string['rsssubscriberssdiscussions'] = 'Wywietl RSS feed dla $a dyskusji';
$string['rsssubscriberssposts'] = 'Wywietl RSS feed dla $a postw';
$string['search'] = 'Szukaj';
$string['searchforums'] = 'Szukaj w forach';
$string['searcholderposts'] = 'Przeszukaj dawniejsze posty...';
$string['searchresults'] = 'Szukaj w rezultatach';
$string['sendinratings'] = 'Wylij moje ostatnie oceny';
$string['showsubscribers'] = 'Wywietl/modyfikuj uytkownikw zapisanych na forum';
$string['singleforum'] = 'Pojedyncza prosta dyskusja';
$string['startedby'] = 'Rozpoczta przez';
$string['subject'] = 'Temat';
$string['subscribe'] = 'Zapisz si na to forum';
$string['subscribeall'] = 'Zapisz wszystkich do tego forum';
$string['subscribed'] = 'Zapisany na forum';
$string['subscribenone'] = 'Wypisz wszystkich z tego forum';
$string['subscribers'] = 'Zapisani na forum';
$string['subscribersto'] = 'Zapisani na \'$a \'';
$string['subscribestart'] = 'Przesyaj mi kopie postw z tego forum poczt elektroniczn';
$string['subscribestop'] = 'Nie chc otrzymywa kopii postw z tego forum';
$string['subscription'] = 'Zapisanie si na forum';
$string['subscriptions'] = 'Zapisy na fora';
$string['unsubscribe'] = 'Wypisz si z tego forum';
$string['unsubscribed'] = 'Wypisany z forum';
$string['unsubscribeshort'] = 'Wypisz';
$string['yesforever'] = 'Tak, na zawsze';
$string['yesinitially'] = 'Tak, wstpnie';
$string['youratedthis'] = 'Ocenie(a) to';
$string['yournewtopic'] = 'Twoja nowa dyskusja';
$string['yourreply'] = 'Twoja odpowied';

?>
